@@ -19,7 +19,8 @@ List* ListImport::from_plaintext(QString filename) {
 			return 0;
 	}
 	// convert to xml
-	QTextStream xml;
+	QString xmlStr;
+	QTextStream xml(&xmlStr);
 	QTextStream in(&file);
 	xml << "<list name='" << filename << "' state='2'>";
 
@@ -43,9 +44,9 @@ List* ListImport::from_plaintext(QString filename) {
 			}
 
 			int c=0;
-			while (line[c].isSpace() and c < line.size())
-				c++;
-			if (c) line.remove(0,c);
+			while (line[c].isSpace() and c++ < line.size()) {
+				if (c) line.remove(0,c);
+			}
 			if (line.size() > 0)
 				xml << "<item wanted='1' bought='0' desc='" << line << "' note=''/>";
 		}
@@ -57,7 +58,7 @@ List* ListImport::from_plaintext(QString filename) {
 
 	DEBUG("import from : " <<filename <<"\n"<<xml);
 
-	return new Shopper::List(xml.readAll());
+	return new Shopper::List(xmlStr);
 }
 
 }
