@@ -21,10 +21,17 @@
 #define SHOPPER_UI_NOTIFY_H
 
 #include <QSystemTrayIcon>
+#include <QIcon>
+#include <QMessageBox>
 
 namespace Shopper
 {
-	class Notify : public QSystemTrayIcon
+	class Notify :
+#ifndef Q_OS_FREMANTLE
+	 public QSystemTrayIcon
+#else
+	public QObject
+#endif
 	{
 		Q_OBJECT;
 	public:
@@ -32,7 +39,7 @@ namespace Shopper
 		
 		void showMessage ( const QString & title,
 								   const QString & message,
-								   MessageIcon icon = Information,
+//								   MessageIcon icon = Information,
 								   int millisecondsTimeoutHint = 10000);
 	};
 }
